*******************************************************.
*** BiH, LSMS 2001, Country level data              ***.
***                                                 ***.
*** Program file:   CONS_AGGREGATE sps              ***.
*** Data files used: PRICEINDEX sav                 ***.
***                  HHCHAR sav                     ***.
***                  IMPUTEDRENT SAV                ***.
***                  UTILITY sav                    ***.
***                  DURABLES sav                   ***.
***                  EDUC_EXP sav                   ***.
***                  DAILYEXP1 sav                  ***.
***                  DAILYEXP2 sav                  ***.
***                  FOOD sav                       ***.
***                  NONFOODPART1 sav               ***.
***                  NONFOODPART2 sav               ***.
*** Output files: CONS_AGGREGATE sav                ***.
***               REF_HHLD sav                      ***.
***                                                 ***.
*** Creating the consumption aggregate-putting      ***.
*** together the pieces:  Housing (rent), utilities ***.
*** use value of durable goods, education spending  ***.
*** food expenditures, production and gifts, (this  ***.
*** includes both seasonal and other), other non-   ***.
*** food expenditures                               ***.
***                                                 ***.
*** This file also creates a new file containing    ***.
*** only those households whose per capita          ***.
*** consumption is from the 10th to 30th percentile ***.
*** in other words, the reference households for the***.
*** food basket                                     ***.
*******************************************************.

*******************************************************.
*** start with household characteristics file       ***.
*******************************************************.

get file='c:\bih\hhchar.sav'.
sort cases by muncode gnd numist hid.

*******************************************************.
*** add in all the files with the components of     ***.
*** household consumption                           ***.
*** use value of housing=Imputedrent sav            ***.
*** utilities=utility sav                           ***.
*** use value of durables=durables sav              ***.
*** education=educ_exp sav                          ***.
*** Module 11, a1=dailyexp1 sav                     ***.
*** Module 11, a2=dailyexp2 sav                     ***.
*** Module 11, b1 and b2=food sav                   ***.
*** Module 11, c1=nonfoodpart1 sav                  ***.
*** Module 11, c2=nonfoodpart2 sav                  ***.
*******************************************************.

match files file=* /file='c:\bih\imputedrent.sav'
 /file='c:\bih\utility.sav'
 /file='c:\bih\durables.sav'
 /file='c:\bih\educ_exp.sav'
 /file='c:\bih\dailyexp1.sav'
 /file='c:\bih\dailyexp2.sav'
 /file='c:\bih\food.sav'
 /file='c:\bih\nonfoodpart1.sav' 
 /file='c:\bih\nonfoodpart2.sav'
 /by muncode gnd numist hid.

freq /var muncode /format notable /statistics min max.

********************************************************.
*** add in price adjustment factor                   ***.
********************************************************.

sort cases by muncode gnd numist.

match files file=* /table='c:\bih\priceindex.sav'
 /by muncode gnd numist.

freq /var pindex /format notable /statistics default median.

********************************************************.
*** compute yearly total household consumption       ***.
********************************************************.

compute rent=0.
if (usehsng>0) rent=usehsng.
compute utilexp=0.
if (totutili>0) utilexp=totutili.
compute durables=0.
if (durable>0) durables=durable.
compute edexp=0.
if (educexp>0) edexp=educexp.
compute nfa1=0.
if (dayexp1>0) nfa1=dayexp1.
compute mealsout=0.
if (dayexp2 >0) mealsout=dayexp2.
compute foodb1_2=0.
if (totfoodc >0) foodb1_2= totfoodc.
compute nfc1=0.
if (totnfc1 >0) nfc1=totnfc1.
compute nfc2 =0.
if (totnfc2 >0) nfc2=totnfc2. 

compute yrcons=rent + utilexp + durables + edexp + nfa1 + mealsout + foodb1_2
 + nfc1 + nfc2.
variable label yrcons 'Annual hhld total consumption'.

********************************************************.
*** adjust annual consumption for cost of living     ***.
********************************************************.

compute adjyrcon=yrcons/pindex.
variable label adjyrcon 'Yrly tot.consump. adj. for cost of living'.

********************************************************.
*** create per capita annual consumption             ***.
********************************************************.

compute pcayrcon=adjyrcon/hhldsize.
variable label pcayrcon 'Percapita adj. yrly consumption'.

********************************************************.
*** create per adult equivalent annual consumption   ***.
********************************************************.

compute pae_cons = adjyrcon/pae_oecd.

variable label pae_cons 'Per adult equ cons, yr, adj'.

******************************************************.
*** Construct the normalized per adult equivalent  ***.
*** here use the per adult equivalent calculated   ***.
*** in f_hhchar--normalize for a 'pivot' family    ***.
******************************************************.

freq /var adult child.

compute typical=0.
if (adult eq 1 and child eq 0) typical=1.
if (adult eq 1 and child eq 1) typical=2.
if (adult eq 1 and child eq 2) typical=3.
if (adult eq 2 and child eq 0) typical=4.
if (adult eq 2 and child eq 1) typical=5.
if (adult eq 2 and child eq 2) typical=6.
if (adult eq 3 and child eq 0) typical=7.
if (adult eq 3 and child eq 1) typical=8.
if (adult eq 3 and child eq 2) typical=9.
if (adult eq 4 and child eq 0) typical=10.
if (adult eq 4 and child eq 1) typical=11.
if (adult eq 4 and child eq 2) typical=12.
if (adult eq 5 and child eq 0) typical=13.
if (adult eq 5 and child eq 1) typical=14.
if (adult eq 5 and child eq 2) typical=15.

freq /var typical.

******************************************************.
*** so the pivot family is two adults (most common ***.
*** household-67 percent of all households have no ***.
*** children under 14 in the household)            ***.
***                                                ***.
*** --> so the adult equivalent consumption is     ***.
***                                                ***.
*** ADJYRCON    OECD pivot family (1.7)            ***.
*** -------  * ----------------------------        ***.
*** (pae_OECD)  number of members pivot family (2) ***.
***                                                ***.
*** creating normalized, per adult equivalent      ***.
*** consumption:                                   ***.
*** -->npaeoecd: OECD adjustmentt, normalizing     ***.
******************************************************.

compute npaecons=((adjyrcon/pae_oecd)*(1.7/2)).

variable label npaecons 'Normalized-Per adutl equ cons, yr, adj'.

sort cases by muncode gnd numist hid.

save /outfile='c:\bih\cons_aggregate.sav'.

freq /var yrcons /ntiles=10 /format notable /statistics default median.

freq /var adjyrcon pcayrcon pae_cons npaecons /ntiles 10 /format notable
 /statistics default median.

means tables = adjyrcon by muncode.
means tables = pcayrcon by muncode.
means tables = pae_cons by muncode.
means tables = npaecons by muncode.

*********************************************************.
*** now select out the reference households who will  ***.
*** be the base for creating the food basket          ***.
*** Use all households from the 10th-30th percentiles ***.
*********************************************************.

weight by whhd.

rank /variables = pcayrcon 
 /ntiles (10).

rename var (npcayrco= decile).
freq /var decile.

compute refhhld=0.
if (decile ge 2 and decile le 3) refhhld=1.

select if (refhhld eq 1).

save /outfile='c:\bih\ref_hhld.sav'.
