******************************************************************************.
*** BiH LSMS 2001, Country Level Data 2001                                 ***.
***                                                                        ***.
*** Syntax File:  DAILYEXP1 sps                                            ***.
*** Data file: C:\BIH\M11_A1 sav                                           ***.
*** Output file: C:\BIH\DAILYEXP1 sav                                      ***.
***                                                                        ***.
*** For Consumption Aggregate                                              ***.
*** Cleaning of data & construction of annual expenditures for daily items ***.
*** in part A of Module 11                                                 ***.
******************************************************************************.

get file='C:\bih\M11_A1.sav'.

freq /var mba1_q00.

temporary.
select if (sysmis(mba1_q00)).
list.

******************************************************************************.
*** There are 18 cases where mba1_q00 is missing, all of these have no as  ***.
*** answer for mba1_q01 and either zero or missing for mba1_q02, for those ***.
*** with zero, recode to missing                                           ***.
******************************************************************************.

do if (sysmis(mba1_q00)).
recode mba1_q02 (0=SYSMIS)  .
end if.

freq /var mba1_q01.

temporary.
select if ((sysmis(mba1_q01)) or (mba1_q01 ne 1 & mba1_q01 ne 2)).
list.

*******************************************************************************.
*** Variable mba1_q01 contains 2 NZ=7 Values and 1 BO=8 Value and 19 missing***.
*** values--- All of them should be transformed into 2 Value, ie Item is    ***.
*** not purchased because there is no Value of Item                         ***.
*******************************************************************************.

if (mba1_q01 ne 1 and mba1_q01 ne 2) mba1_q01=2.
if (sysmis(mba1_q01)) mba1_q01=2.

freq /var mba1_q01.

temporary.
select if (mba1_q01 eq 1 & (mba1_q02 eq 0 or (sysmis(mba1_q02))
 or mba1_q02 ge 777.00)).
list.

*******************************************************************************.
*** There are 14 Missing Values and 4 cases where the Purchase of Item is 1 ***.
***  and the value of Item is 0-- For the cases where value=0, the question ***
***  Purchase of Item (mbq1_q01) is changed into 2-Value and Missing Values ***
***  should be imputed with Median                                          ***.
*******************************************************************************.

if (mba1_q01 eq 1 & mba1_q02 eq 0) mba1_q01=2.

*******************************************************************************.
*** Select only those cases where purchased item                            ***.
*******************************************************************************.

select if (mba1_q01 = 1).

*******************************************************************************.
***Replace missing values with an appropriate median                        ***.
*******************************************************************************.

missing value mba1_q02 (0, 777 thru highest).

compute yesdata = 0.
if (mba1_q02 > 0) yesdata = 1.

aggregate outfile='c:\bih\gndmed.sav'
 /break muncode gnd mba1_q00
 /gnumber 'No of valid data for gnd'=sum(yesdata)
 /gmed 'gnd median'=median(mba1_q02)
 /gsd 'gnd standdev'=sd(mba1_q02).

aggregate outfile='c:\bih\munmed.sav'
 /break muncode  mba1_q00
 /mnumber 'No of valid data for municipality'=sum(yesdata)
 /mmed 'munic median'=median(mba1_q02)
 /msd 'munic standdev'=sd(mba1_q02).

aggregate outfile='c:\bih\entmed.sav'
 /break entity  mba1_q00
 /enumber 'No of valid data for entity'=sum(yesdata)
 /emed 'entity median'=median(mba1_q02)
 /esd 'entity standdev'=sd(mba1_q02).

aggregate outfile='c:\bih\bhmed.sav'
 /break   mba1_q00
 /bhnumber 'No of valid data for bh'=sum(yesdata)
 /bhmed 'bh median'=median(mba1_q02)
 /bhsd 'bh standdev'=sd(mba1_q02).

sort cases by muncode gnd mba1_q00.
 
match files /file=* /table='C:\bih\gndmed.sav'
 /by muncode gnd mba1_q00.

sort cases by muncode mba1_q00.
 
match files /file=* /table='C:\bih\munmed.sav'
 /by muncode mba1_q00.

sort cases by entity mba1_q00.
 
match files /file=* /table='C:\bih\entmed.sav'
 /by entity mba1_q00.

sort cases by mba1_q00.
 
match files /file=* /table='C:\bih\bhmed.sav'
 /by mba1_q00.

if (gnumber >= 5) amedian = gmed.
if (gnumber < 5 and mnumber >= 5) amedian = mmed.
if (gnumber < 5 and mnumber < 5 and enumber >= 5) amedian = emed.
if (gnumber < 5 and mnumber < 5 and enumber < 5 and bhnumber >= 5) amedian = bhmed.

missing values mba1_q02 ().

if (mba1_q01 eq 1 and mba1_q02 ge 777.00) mba1_q02 = amedian.
if ((mba1_q02 > (bhmed + (6*bhsd))) or (mba1_q02 < (bhmed - (6*bhsd)))) mba1_q02 = amedian.

freq /var = mba1_q01 mba1_q02
  /format notable /statistics default median.

*******************************************************************************.
*** Calculating annual amounts                                              ***.
*** Assumptions:  daily parking is related to work, use 46 weeks per year   ***.
***               for work (52-4 for vacations and 2 for various holidays)  ***.
***            :  haircuts are not really weekly, multiply by 12 for months ***.
*******************************************************************************.

compute exp11_a1 = 0.
If (mba1_q00 ge 1 and mba1_q00 le 3) exp11_a1= mba1_q02 * 52.
if (mba1_q00 eq 4) exp11_a1 = mba1_q02 * 46.
if (mba1_q00 eq 5) exp11_a1 = mba1_q02 * 12.

*******************************************************************************.
*** Create a household level file with sum of items in Part A1              ***.
*******************************************************************************.

aggregate outfile='c:\bih\dailyexp1.sav'
 /break muncode gnd numist hid
 /dayexp1 'Sum of exp11_a1'=sum(exp11_a1).

get file='c:\bih\dailyexp1.sav'.
freq /var all /format notable /statistics default mode median.










