****************************************************************************.
*** BiH 2001 LSMS, Country Level Data                                    ***.
***                                                                      ***.
*** Syntax file:  DAILYEXP2 sps                                          ***.
*** Data file:  C:\BIH\M11_A2 sav                                        ***.
*** Output file: C:\BIH\DAILYEXP2 sav                                    ***.
***                                                                      ***.
*** For Consumption Aggregate                                            ***.
*** Data cleaning and construction of annual expenditures for food       ***.
*** consumed outside the home, Module 11, part A2                        ***.
****************************************************************************.

get file='c:\bih\M11_A2.sav'.

freq /var=mba2_q03 /ORDER=  ANALYSIS .

temporary.
select if (sysmis(mba2_q03) or mba2_q03 ge 77). 
list.

****************************************************************************.
*** Variable mba2_q03 contains 4 missing and 2 NZ Values. All of them    ***.
*** should be transformed into 0 Value because there is no Value of Meal ***.
****************************************************************************.

if (sysmis(mba2_q03) or mba2_q03 ge 77) mba2_q03 = 0.

freq /var=mba2_q03 /ORDER=  ANALYSIS .

temporary.
select if (mba2_q03 ne 0).
freq /var =mba2_q04 /ORDER=  ANALYSIS .

temporary.
select if (mba2_q03 > 0 and (mba2_q04  = 0 or sysmis(mba2_q04) or mba2_q04 ge 777)). 
list.

****************************************************************************.
*** Where mba2_q03 equals to 2 and mba2_q04 eq 0 or missing, assume the  ***.
*** mba2_03=2 is an interviewer mistake- they put in '2' for 'no' as in  ***.
*** previous table forgetting that this was number of meals, not yes/no  ***.
*** question                                                             ***.          
*** Where mba2_q03 is > 0 (and ne 2) and mba2_q04  = 0  or missing the   ***.
*** variable mba2_q04 should be transformed into 777.00 and they will be ***.
*** later imputed with unit price median from the GND                    ***.                                                                   ***.
****************************************************************************.

if (mba2_q03 eq 2 and (mba2_q04 = 0 or sysmis(mba2_q04) or mba2_q04 ge 777)) mba2_q03 = 0.

freq /var mba2_q03 mba2_q04.

****************************************************************************.
*** drop all the records with no consumption of food outside home        ***.
****************************************************************************.

select if (mba2_q03 gt 0).

freq /var =mba2_q04 /ORDER=ANALYSIS .

if (mba2_q04  = 0 or sysmis(mba2_q04) or mba2_q04 ge 777) mba2_q04 = 777. 

temporary.
select if (mba2_q04 eq 777). 
list.

****************************************************************************.
*** Replace missing values using an appropriate unit price median        ***.
****************************************************************************.

****************************************************************************.
*** Calculating unit prices for items                                    ***.
*** Avoid missing meal values                                            ***.
****************************************************************************.

IF (mba2_q04 lt 777) unitpric = mba2_q04 / mba2_q03 .

freq /var = unitpric /order=analysis.

****************************************************************************.
*** Calculating appropriate unit price medians                           ***.
****************************************************************************.

compute yesdata = 0.
if (mba2_q04 ne 777) yesdata = 1.

aggregate outfile='c:\bih\gndmed2.sav'
 /break muncode gnd mba2_q00
 /gnumber 'No of valid data for gnd'=sum(yesdata)
 /gmed 'gnd median'=median(unitpric)
 /gsd 'gnd standdev'=sd(unitpric).

aggregate outfile='c:\bih\munmed2.sav'
 /break muncode mba2_q00
 /mnumber 'No of valid data for municipality'=sum(yesdata)
 /mmed 'munic median'=median(unitpric)
 /msd 'munic standdev'=sd(unitpric).

aggregate outfile='c:\bih\entmed2.sav'
 /break entity mba2_q00
 /enumber 'No of valid data for entity'=sum(yesdata)
 /emed 'entity median'=median(unitpric)
 /esd 'entity standdev'=sd(unitpric).

aggregate outfile='c:\bih\bhmed2.sav'
 /break mba2_q00
 /bhnumber 'No of valid data for bh'=sum(yesdata)
 /bhmed 'bh median'=median(unitpric)
 /bhsd 'bh standdev'=sd(unitpric).

sort cases by muncode gnd mba2_q00.
 
match files /file=* /table='C:\bih\gndmed2.sav'
 /by muncode gnd mba2_q00.

sort cases by muncode mba2_q00.
 
match files /file=* /table='C:\bih\munmed2.sav'
 /by muncode mba2_q00.

sort cases by entity mba2_q00.
 
match files /file=* /table='C:\bih\entmed2.sav'
 /by entity mba2_q00.

sort cases by mba2_q00.
 
match files /file=* /table='C:\bih\bhmed2.sav'
 /by  mba2_q00.

if (gnumber >= 5) amedian = gmed.
if (gnumber < 5 and mnumber >= 5) amedian = mmed.
if (gnumber < 5 and mnumber < 5 and enumber >= 5) amedian = emed.
if (gnumber < 5 and mnumber < 5 and enumber < 5 and bhnumber >= 5) amedian = bhmed.

if (mba2_q04 eq 777) mba2_q04 = mba2_q03*amedian.
 
freq /var=mba2_q04 /STATISTICS=STDDEV MINIMUM MAXIMUM MEAN MEDIAN MODE SUM.

********************************************************************.
*** replace outliers with relevant median                        ***.
********************************************************************.

if ((unitpric > (bhmed1 + (3*bhsd1))) or (unitpric < (bhmed1 - (3*bhsd1)))) mba2_q04 = amedian*mba2_Q03.

freq /var = mba2_q04 /STATISTICS=STDDEV MINIMUM MAXIMUM MEAN MEDIAN MODE SUM.

*********************************************************************.
*** Calculating annual amounts                                    ***.
*** Assumption is that many people eat meals out of the home when ***.
*** they work, so for all cases where the number of meals is a    ***.
*** five or a multiple of five, assume that these are work-related***.
*** meals, assume 46 working weeks in year (52-4 weeks of vacation***.
*** minus two weeks of holidays)                                  ***.
*** For all other cases, multiply by 52 to get annual             ***.
*********************************************************************.

freq /var mba2_q03.

compute exp11_a2=0.

do if (mba2_q03 eq 5 or mba2_q03 eq 10 or mba2_q03 eq 15 or mba2_q03 eq 20 or mba2_q03 eq 25 or mba2_q03 eq 30 
 or mba2_q03 eq 35 or mba2_q03 eq 40).
compute exp11_a2=mba2_q04*46.
else.
compute exp11_a2=mba2_q04*52.
end if.

freq /var exp11_a2.

freq /var =exp11_a2 /STATISTICS=STDDEV MINIMUM MAXIMUM MEAN MEDIAN MODE SUM
  /ORDER=ANALYSIS .

***************************************************************************.
*** Create a household level file with sum of items in Part A2          ***.
***************************************************************************.

aggregate outfile='c:\bih\Dailyexp2.sav'
 /break muncode gnd numist hid
 /dayexp2 'Sum of exp11_a2'=sum(exp11_a2).

get file='c:\bih\dailyexp2.sav'.
freq /var all /format notable /statistics default mode median.


