*********************************************************************.
***  BiH, LSMS 2001, Country Level Data                           ***.
***                                                               ***.
***  Program file:  HHCHAR sps                                    ***.
***  Data file used:  C:\BIH\M1 sav                               ***.
***  Output file: C:\BIH\HHCHAR sav                               ***.
***                                                               ***.
***  Create household composition variables for:                  ***.
***  Per capita (hhldsize),                                       ***.
***  Per adult equivalent, OECD, where first adult has weight     ***.
***      of 1, additional adults have weight of .7 and children   ***.
***      (child is defined as 13 or younger) has weight of 0.5    ***.
***  Household head:  age, sex, marital status                    ***.
***                                                               ***.
***  Also creates the two weight variables that must be used      ***.
***  in all analyses of the data sets                             ***.
*********************************************************************.

get file='c:\bih\m1.sav'.

freq /var m1_q_b m1_q03 m1_q02 m1_q05 m1_q11.

*********************************************************************.
*** drop all non-members                                         ***.
*********************************************************************.

select if (m1_q11 eq 1).

*********************************************************************.
*** have one person, with inappropriate code for m1_q05, marital  ***.
*** status- person lives alone, make assumption that real answer  ***.
*** is code 5 (widowed/divorced) and interviewer wrote the skip   ***.
**  code '8' by mistake                                           ***.
*********************************************************************.

temporary.
select if (m1_q05 lt 1 or m1_q05 gt 5 and m1_q_b gt 12).
list.

if (muncode eq 10871 and gnd eq 34 and numist eq 53 and hid eq 21 and
 pid eq 1) m1_q05=5.

*********************************************************************.
*** create new variables                                          ***.
*********************************************************************.

compute adul=0.
if (m1_q_b ge 14) adul=1.
compute chil=0.
if (m1_q_b lt 14) chil=1.

compute person=1.

compute headyrs=0.
if (m1_q03 eq 1) headyrs=m1_q_b.
compute headgen=0.
if (m1_q03 eq 1) headgen=m1_q02.
compute headmar=0.
if (m1_q03 eq 1) headmar=m1_q05.

freq /var adul chil person headyrs headgen headmar.

sort cases by muncode gnd numist hid.

aggregate outfile='c:\bih\agg_hhc1.sav'
 /break muncode gnd numist hid 
 /adult 'No. adults in hhld' = sum(adul)
 /child 'No. children in hhld<14' = sum(chil)
 /headage 'Yrs of age, head of hhld'=sum(headyrs)
 /headsex 'Gender of hhld head' = sum(headgen)
 /headmarr 'Marital status, hhldhead'=sum(headmar)
 /hhldsize 'No. hhld members'=sum(person).

match files file=* /table='c:\bih\agg_hhc1.sav'
 /by muncode gnd numist hid /map.

*********************************************************.
*** construct the per adult equivalent variable PAE   ***.
*** based on OECD, where first adult has weight of    ***.
*** 1 and all additional adults have weight of .7     ***.
*** and children (under 14) have weight of .5         ***.
*** Actually this is the old OECD scale, the new      ***.
*** version is too extreme                            ***.
*********************************************************.

compute pae_oecd=1+(.7*(adult-1)) + (child*.5).
variable label pae_oecd 'Adult equivalents, OECD'.

*********************************************************.
*** create file with only household characteristics   ***.
*** ie one record per household, agg variables        ***.
*********************************************************.

select if (m1_q03 eq 1).

*********************************************************.
*** Create the weight variables for individual level  ***.
*** files and household level files, from Peter Lynn  ***.
*** See Basic Information document for details        ***.
*********************************************************.

if (muncode eq 10022) wpop= 43.
if (muncode eq 10855) wpop= 425.
if (muncode eq 10235) wpop= 1798.
if (muncode eq 10642) wpop= 238.
if (muncode eq 10111) wpop= 236.
if (muncode eq 10740) wpop= 63.
if (muncode eq 11134) wpop= 323.
if (muncode eq 10936) wpop= 675.
if (muncode eq 10138) wpop= 314.
if (muncode eq 10952) wpop= 295.
if (muncode eq 11193) wpop= 162.
if (muncode eq 10839) wpop= 179.
if (muncode eq 10880) wpop= 168.
if (muncode eq 10871) wpop= 106.
if (muncode eq 11088) wpop= 85.
if (muncode eq 11185) wpop= 83.
if (muncode eq 10189) wpop= 793.
if (muncode eq 11061) wpop= 182.
if (muncode eq 11126) wpop= 245.
if (muncode eq 10928) wpop= 559.
if (muncode eq 10391) wpop= 339.
if (muncode eq 10405) wpop= 1358.
if (muncode eq 10448) wpop= 391.
if (muncode eq 10731) wpop= 898.
if (muncode eq 11177) wpop= 499.

compute whhd=wpop* hhldsize.

variable label wpop 'Weight for indiv level files'
 whhd 'Weight for hhld level files'.

save /outfile='c:\bih\hhchar.sav' 
 /keep entity muncode gnd numist hid mun_type adult
  child headage headsex headmarr hhldsize pae_oecd whhd wpop.
