************************************************.
*** BiH 2001, LSMS, Country level data       ***.
***                                          ***.
*** Program file IMPUTEDRENT sps             ***.
*** Uses data file C:\BIH\M2_AB sps          ***.
*** Output file C:\BIH\IMPUTEDRENT           ***.
***                                          ***.
*** For the Consumption Aggregate            ***.
*** Calculate the use value of housing or    ***.
***    imputed rent                          ***.
************************************************.

Get file='C:\bih\M2_AB.sav'.

missing values m2_q38 m2_q36 ().

temporary.
select if (m2_q22 eq 4 and (m2_q38 eq 0 | m2_q38 ge 777)).
freq /var m2_q22 m2_q36 m2_q38.

temporary.
select if ((m2_q22 le 2 | m2_q22 ge 6) and (m2_q36 eq 0 | m2_q36 ge 77777)).
freq /var m2_q22 m2_q36 m2_q38.

************************************************.
*** compute 'rent' variable that has a valid ***.
*** amount only if 'true renter'             ***.
************************************************.

compute rent=0.
if (m2_q22 eq 4 and m2_q38 gt 0 and m2_q38 lt 777) rent = m2_q38.
freq /var rent /statistics default median.
temporary.
select if (rent gt 0).
freq /var rent /statistics default median.

************************************************.
*** compute 'rent' variable that has a valid ***.
*** amount if the person is not a renter     ***.
*** this is the self-reported amount the     ***.
*** person thinks s/he would have to pay if  ***.
*** s/he paid rent                           ***.
************************************************.

compute ifrent=0.
if  (((m2_q22 ge 1 and m2_q22 le 2 )| (m2_q22 ge 6 and m2_q22 le 9)) 
 and m2_q36 gt 0 and m2_q36 lt 77777) ifrent = m2_q36.
freq /var ifrent /statistics default median.
temporary.
select if (ifrent gt 0).
freq /var ifrent /statistics default median.

***************************************************.
*** compute 'anyrent' variable that includes    ***.
*** either rent or ifrent                       ***.
***************************************************.

compute anyrent=ifrent+rent.

temporary.
select if (anyrent>0).
freq /var anyrent /statistics default median.

temporary.
select if (anyrent gt 0).
freq /var anyrent /statistics default median.

temporary.
select if (m2_q22 eq 4 and rent >0).
freq /var rent /statistics default median.

sort cases by entity mun_type.
aggregate /outfile='c:\bih\medrent.sav'
 /break entity mun_type
 /medrent 'Median anyrent, entity mun)type'=median(anyrent)
 /stdrent 'Std of anyrent, entity mun_type'=sd(anyrent).

match files file=* /table='c:\bih\medrent.sav'
 /by entity mun_type.

if ((anyrent < (medrent-(6*stdrent))) or (anyrent > (medrent+(6*stdrent)))) anyrent=medrent.

*********************************************.
****  create dummy variables              ***.
*********************************************.

*********************************************.
***  Dummy from question m2_q01           ***.
***  Dummy za m2_q01                      ***.
*********************************************.

compute flat = 0.
if (m2_q01 = 1 or m2_q01 = 4) flat = 1.

Variable labels flat 'Dummy za stan'.
value labels flat 1 "Stan" 0 "Ostalo".

compute house = 0.
if (m2_q01 = 2 or m2_q01 = 3) house = 1.
Variable labels house 'Dummy za kucu'.
value labels house 1 "Kuca" 0 "Ostalo".

*********************************************.
*** Dummy from question m2_q02            ***.
*** Dummy za m2_q02                       ***.
*********************************************.

compute gcond = 0.
if (m2_q02 = 1 or m2_q02 = 2) gcond = 1.
Variable labels gcond 'Dummy za uslove stanovanja'.
value labels gcond 1 "Uslovno" 0 "Neuslovno".

*********************************************.
*** Dummy from question m2_q06            ***.
*** Dummy za m2_q06                       ***.
*********************************************.

if (m2_q6a = 0) m2_q6a = 2.
if (m2_q6b = 0) m2_q6b = 2.
if (m2_q6c = 0) m2_q6c = 2.
if (m2_q6d = 0) m2_q6d = 2.
if (m2_q6e = 0) m2_q6e = 2.
if (m2_q6f = 0) m2_q6f = 2.
if (m2_q6g = 0) m2_q6g = 2.
if (m2_q6h = 0) m2_q6h = 2.
if (m2_q6i = 0) m2_q6i = 2.
if (m2_q6j = 0) m2_q6j = 2.

compute extroom = 0.
if (m2_q6a = 1 and m2_q6b = 1 and m2_q6c = 1 and m2_q6d =1 and m2_q6f = 1) extroom = 1.
Variable labels extroom 'Dummy za posebne prostorije'.

compute stroom = 0.
if (m2_q6a = 1 and m2_q6b = 1) stroom = 1.
Variable labels stroom 'Dummy za standardne prostorije'.
value labels stroom 1 "Kuhinja i WC" 0 "Ostalo".

*********************************************.
*** Dummy variable for entity             ***.
*** Dummy za entitet                      ***.
*********************************************.

compute dentity = 0.
if (entity = 2) dentity = 1.
Variable labels dentity 'Dummy za entitet'.
value labels dentity 0 "RS" 1 "FBiH".

********************************************.
*** Recoding question m2_q09             ***.
*** Rekodiranje pitanja q09              ***.
********************************************.
 
if (m2_q09 = 2) m2_q09 = 0.
value labels m2_q09 1 "Yes" 0 "No".

*********************************************.
*** Dummy from question m2_q12            ***.
*** Dummy za M2_q12                       ***.
*********************************************.

compute pwater = 0.
if (m2_q12 = 1 or m2_q12 = 2) pwater = 1.
Variable labels pwater 'Dummy za pitku vodu'.
value labels pwater 1 "Tekuca" 0 "Ostalo".

*********************************************.
*** Dummy from question m2_q21            ***.
*** Dummy za m2_q21                       ***.
*********************************************.

compute phone = 0.
if (m2_q21 = 1) phone = 1.
Variable labels phone 'Dummy za telefon'.
value labels phone 1 "Vlastiti" 0 "Ostalo".

*********************************************.
*** Dummy for municipal type, mun_type    ***.
*** Dummy za mun_type                     ***.
*********************************************.

compute durban = 0.
if (mun_type  = 1) durban = 1.
Variable labels durban 'Dummy za urban'.
value labels durban 1 "Urban" 0 "Ostalo".

compute drural = 0.
if (mun_type  = 3) drural = 1.
Variable labels drural 'Dummy za rural'.
value labels drural 1 "Rural" 0 "Ostalo".

*********************************************.
*** Dummy from question m2_q19            ***.
*** Dummy za pitanja m2_q19               ***.
*********************************************.

compute dsewer =0.
if (m2_q19 eq 1) dsewer =1.
Variable labels dsewer 'Dummy za kanalizaciju'.
value labels dsewer 1 "Sewer" 0 "Ostalo".

*********************************************.
*** Dummy from question m2_q20            ***.
*** Dummy za pitanja m2_q20               ***.
*********************************************.

compute dmunheat=0.
if (m2_q15=1) dmunheat=1.
variable labels dmunheat  'Dummy za centralno grijanje'.
value labels dmunheat 1 'Ima cent.g.'  0 'Nema cent.g.'.

*********************************************.
*** Dummy for municipalities              ***.
*** Dummy za muncode                      ***.
*********************************************.

compute dbanjal=0.
if (muncode=10022) dbanjal=1.
variable labels dbanjal  'Dummy za Banja Luka'.
value labels dbanjal 1 'Banja Luka'  0 'ostala'.

compute dsaraj=0.
if (muncode=10880 or muncode=10839 ) dsaraj=1.
variable labels dsaraj  'Dummy za Sarajevo'.
value labels dsaraj 1 'Sarajevo'  0 'ostala'.

compute dtuzla=0.
if (muncode=11088) dtuzla=1.
variable labels dtuzla  'Dummy za Tuzlu'.
value labels dtuzla 1 'Tuzla'  0 'ostala'.

compute dprijed=0.
if (muncode=10740) dprijed=1.
variable labels dprijed  'Dummy za Prijedor'.
value labels dprijed 1 'Prijedor'  0 'ostala'.

compute dnovig=0.
if (muncode eq 10111) dnovig=1.

compute dsamac=0.
if (muncode eq 10138) dsamac=1.

compute dbreza=0.
if (muncode eq 10189) dbreza=1.

compute dcajni=0.
if (muncode eq 10235) dcajni=1.

compute dgrada=0.
if (muncode eq 10391) dgrada=1.

compute dgrude=0.
if (muncode eq 10405) dgrude=1.

compute dkakan=0.
if (muncode eq 10448) dkakan=1.

compute dmodri=0.
if (muncode eq 10642) dmodri=1.

compute dposus=0.
if (muncode eq 10731) dposus=1.

compute dsrpil=0.
if (muncode eq 10855) dsrpil=1.

compute dnovig=0.
if (muncode eq 10871) dnovig=1.

compute dvogos=0.
if (muncode eq 10928) dvogos=1.

compute dkneze=0.
if (muncode eq 10936) dkneze=1.

compute dsrbac=0.
if (muncode eq 10952) dsrbac=1.

compute dtravn=0.
if (muncode eq 11061) dtravn=1.

compute dvisok=0.
if (muncode eq 11126) dvisok=1.

compute dviseg=0.
if (muncode eq 11134) dviseg=1.

compute dzavid=0.
if (muncode eq 11177) dzavid=1.

compute dzenic=0.
if (muncode eq 11185) dzenic=1.

compute dzvorn=0.
if (muncode eq 11193) dzvorn=1.

************************************************.
*** Square meters, from question m2_q04      ***.
*** Za pitanja m2_q04                        ***.
************************************************.

if (m2_q04 gt 0 and m2_q04 lt 777) sqmeter=m2_q04.
if (m2_q05 gt 0 and m2_q05 lt 77) numrooms=m2_q05.

*******************************************************************.
*** Data Cleaning                                               ***.
*** There are 44 housholds with missing information on sqmeters ***.
*** 39 of these have numrooms--use the average sqmeters by room ***.
*** for the other 5 hhlds, use the mean sqmeters in their       ***.
*** municipality and group of enumeration areas                 ***.
*******************************************************************.

means tables=sqmeter by numrooms.
means tables=sqmeter by muncode by gnd.

if (sysmis(sqmeter) and numrooms eq 1)sqmeter=41.
if (sysmis(sqmeter) and numrooms eq 2)sqmeter=58.
if (sysmis(sqmeter) and numrooms eq 3)sqmeter=74.
if (sysmis(sqmeter) and numrooms eq 4)sqmeter=95.
if (sysmis(sqmeter) and numrooms eq 5)sqmeter=121.
if (sysmis(sqmeter) and muncode eq 10022 and gnd eq 532)sqmeter=74.
if (sysmis(sqmeter) and muncode eq 10111 and gnd eq 13)sqmeter=42.5.

freq /var sqmeter.

*******************************************************************.
*** do regressions based on natural log of rent                 ***.
*******************************************************************.

compute lnrent=ln(rent).
compute lnifrent=ln(ifrent).
compute lnanyren=ln(anyrent).

freq /var lnrent lnifrent lnanyren /format notable /statistics default median.

temporary.
select if (anyrent >0).
REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT lnanyren
  /METHOD=enter sqmeter numrooms flat house gcond extroom stroom
   dentity pwater phone durban drural dmunheat dbanjal dsaraj
   dtuzla dprijed
 /save=pred(renterb) adjpred(renterba).

***************************************************.
*** Regression by entity                        ***.
*** Regresija po entitetima                     ***.
***************************************************.

temporary.
select if (anyrent >0 and entity eq 1).
REGRESSION
  /MISSING listwise
  /DESCRIPTIVES=corr
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT lnanyren
  /METHOD=stepwise flat house gcond extroom stroom pwater phone
   durban dsewer dmunheat dbanjal dprijed dsamac dcajni dmodri
   dsrpil dkneze dsrbac dviseg dzvorn sqmeter 
  /outfile covb('c:\bih\rent_rs1.sav')
  /save pred(rentrs).

temporary.
select if (anyrent >0 and entity eq 2).
REGRESSION
  /MISSING LISTWISE
  /DESCRIPTIVES=corr
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT lnanyren
  /METHOD=stepwise flat house gcond extroom stroom pwater phone
   durban dsewer dmunheat dsaraj dtuzla dnovig dbreza dgrada
   dgrude dkakan dposus dvogos dtravn dvisok dzavid dzenic sqmeter 
  /outfile covb('c:\bih\rent_fd1.sav')
  /save pred(rentfed).

save /outfile='c:\bih\temprent.sav'.

get file='c:\bih\rent_rs1.sav'
 /rename (const_ flat house gcond extroom stroom pwater phone durban dsewer 
  dmunheat dbanjal dprijed dsamac dcajni dmodri dsrpil dkneze dsrbac dviseg
  dzvorn sqmeter = rconst rflat rhouse rgcond rextroom rstroom rpwater rphone
 rdurban rdsewer rdmunhea rdbanjal rdprijed rdsamac rdcajni rdmodri
 rdsrpil rdkneze rdsrbac rdviseg rdzvorn rsqmeter).
recode rconst rflat rhouse rgcond rextroom rstroom rpwater rphone
 rdurban rdsewer rdmunhea rdbanjal rdprijed rdsamac rdcajni rdmodri
 rdsrpil rdkneze rdsrbac rdviseg rdzvorn rsqmeter (sysmis=0).
compute entity=1.
select if (rowtype_ eq 'EST').
save /outfile='c:\bih\rent_rs2.sav'.

get file='c:\bih\rent_fd1.sav'
 /rename (const_ flat house gcond extroom stroom pwater phone durban dsewer
  dmunheat dsaraj dtuzla dnovig dbreza dgrada
  dgrude dkakan dposus dvogos dtravn dvisok dzavid dzenic sqmeter = fconst 
  fflat fhouse fgcond fextroom fstroom fpwater fphone
  fdurban fdsewer fdmunhea fdsaraj fdtuzla fdnovig fdbreza fdgrada
  fdgrude fdkakan fdposus fdvogos fdtravn fdvisok fdzavid fdzenic fsqmeter).
recode fconst fflat fhouse fgcond fextroom fstroom fpwater fphone
  fdurban fdsewer fdmunhea fdsaraj fdtuzla fdnovig fdbreza fdgrada
  fdgrude fdkakan fdposus fdvogos fdtravn fdvisok fdzavid fdzenic fsqmeter 
  (sysmis=0).
compute entity=2.
select if (rowtype_ eq 'EST').
save /outfile='c:\bih\rent_fd2.sav'.

get file='c:\bih\temprent.sav'.
sort cases by entity.
match files file=* /table='c:\bih\rent_rs2.sav'
 /table='c:\bih\rent_fd2.sav'
 /by entity.

*****************************************************.
*** create ImputedRent sav -the use value of      ***.
*** housing for all or imputed rent               ***.
***                                               ***.
*** Includes:                                     ***.
***    renters (actual payment)                   ***.
***    non-renters but who gave value of what     ***.
***         rent would be (actual response)       ***.
***    non-renters (imputed rent)                 ***.
*** multiply by 12 to get annual rent             ***.
*****************************************************.

recode flat house gcond extroom stroom dentity pwater phone durban dsewer drural
  dmunheat dbanjal dsaraj dtuzla dprijed dnovig dsamac dbreza dcajni dgrada
  dgrude dkakan dmodri dposus dsrpil dvogos dkneze dsrbac dtravn dvisok dviseg
  dzavid dzenic dzvorn sqmeter (sysmis=0). 

missing values anyrent().

if (anyrent gt 0) usehsng=anyrent* 12.
if (anyrent eq 0 and entity eq 1) predrent=rconst + (flat*rflat) + (house*rhouse)
 + (gcond*rgcond) + (extroom*rextroom) + (stroom*rstroom) + (pwater*rpwater)
 + (phone*rphone) + (durban*rdurban) + (dsewer*rdsewer) + (dmunheat*rdmunhea)
 + (dbanjal*rdbanjal) + (dprijed*rdprijed) + (dsamac*rdsamac) + (dcajni*rdcajni)
 + (dmodri*rdmodri) + (dsrpil*rdsrpil) + (dkneze*rdkneze) + (dsrbac*rdsrbac)
 + (dviseg*rdviseg) + (dzvorn*rdzvorn) + (sqmeter*rsqmeter) .

if (anyrent eq 0 and entity eq 2) predrent=fconst + (flat*fflat) + (house*fhouse)
 + (gcond*fgcond) + (extroom*fextroom) + (stroom*fstroom) + (pwater*fpwater)
 + (phone*fphone) + (durban*fdurban) + (dsewer*fdsewer) + (dmunheat*fdmunhea)
 + (dsaraj*fdsaraj) + (dtuzla*fdtuzla) + (dnovig*fdnovig) + (dbreza*fdbreza)
 + (dgrada*fdgrada) + (dgrude*fdgrude) + (dkakan*fdkakan) + (dposus*fdposus)
 + (dvogos*fdvogos) + (dtravn*fdtravn) + (dvisok*fdvisok) + (dzavid*fdzavid)
 + (dzenic*fdzenic) + (sqmeter*fsqmeter).

if (anyrent eq 0) usehsng=(exp(predrent))*12.

variable label usehsng 'Annual use value of housing'.

freq /var usehsng /format notable /statistics default median .

sort cases by muncode gnd numist hid.

save /outfile='c:\bih\ImputedRent.sav'
 /keep muncode gnd numist hid usehsng.


