***********************************************.
*** BiH 2001 LSMS, country level data       ***.
***                                         ***.
*** Program file:  NONFOODPART1 sps         ***.
***                                         ***.
*** Uses data file C:\BIH\M11_C1 sav        ***.
*** Output file: C:\BIH\NONFOODPART1 sav    ***.
***                                         ***.
*** For the Consumption aggregate           ***.
*** Aggregates and cleans annual non-food   ***.
*** expenditures from module 11, Part C1    ***.
***********************************************.

***********************************************.
***Otvaram file za analizu                  ***.
***Open file                                ***.
***********************************************.

get file='c:\bih\m11_c1.sav'.

***********************************************.
*** Provjera frekvencija                    ***.
*** Check frequencies                       ***.
***********************************************.

freq /var mbc1_q1b mbc1_q02 mbc1_q03 /statistics default median.

***********************************************.
*** Ponistavamo sva setovanja missing val   ***.
*** Clear all settings for missing values   ***.
***********************************************.

missing values mbc1_q1b mbc1_q02 mbc1_q03 ().

********************************************************************.
*** Postavljamo vrijednosti svih missing na istu konstantu       ***.
*** radi jednostavnijeg pregleda                                 ***.
*** Set all missing values to constant (-1)                      ***. 
********************************************************************.

recode mbc1_q02 (777777 thru  highest=-1).
recode mbc1_q03 (777777 thru  highest=-1).

***********************************************.
*** Provjeravamo uspjeh                     ***.
*** Check the result                        ***.
***********************************************.

freq /var mbc1_q02 mbc1_q03 /statistics default median. 

*******************************************************************.
*** Pravim listing vrijednosti koje ne odgovaraju               ***.
*** List all cases for which answers don't match                ***.
*** Ima potrosnja- nema vrijednosti                             ***.
*** have  'yes' for consumption, but no values                  ***.
*******************************************************************.

temporary.
select if (mbc1_q1b eq 1 and (mbc1_q02 eq -1 or mbc1_q03 eq -1)).
list /var muncode gnd numist hid mbc1_q00 mbc1_q1b mbc1_q02 mbc1_q03.

**********************************************.
*** Nema potrosnje- postoje vrijednosti    ***.
*** have  'no' for consumption, but there  ***.
*** are values                             ***.
**********************************************.

temporary.
select if (mbc1_q1b eq 2 and (mbc1_q02 > 0  or mbc1_q03 > 0 )).
list /var muncode gnd numist hid mbc1_q00 mbc1_q1b mbc1_q02 mbc1_q03.

*******************************************************************.
*** Uklanjam odgovor 'yes' gdje  potrosnja nema vrijednost      ***.
*** Remove 'yes' where there are both 0 values                  ***.
*******************************************************************.

if ( mbc1_q1b eq 1 and (mbc1_q02 eq 0 and mbc1_q03 eq 0)) mbc1_q1b=2.

*******************************************************************.
*** Validne vrijednosti iz seta nema potrosnje prebacujem u ima ***.
*** potrosnje                                                   ***.       
*** For record with no, but has values, change mbc1_q1b to 1    ***.       
*******************************************************************.

if (mbc1_q1b eq 2 and (mbc1_q02 > 0 or mbc1_q03 > 0 ))  mbc1_q1b=1.

*******************************************************************.
*** snimam u medjufajl radi kontrole rezultata                  ***.
*** make new file for those who have consumption AND have       ***.
*** values for consumption                                      ***.
*******************************************************************.

select if (mbc1_q1b eq 1).
save outfile='c:\bih\tempnonfoodpart1_all.sav'.

*******************************************************************.
*** Racunam medijane i standardne devijacije                    ***.
*** Calculate MEDIAN and SD                                     ***.
*******************************************************************.

*******************************************************************.
*** Prvo se rijesim ovih -1 vrijednosti                         ***.
*** Exclude values with -1 for this                             ***.
*******************************************************************.

missing values mbc1_q02 mbc1_q03 (-1).

*******************************************************************.
*** Uvodim varijable pomocu kojih cu da brojim slucajeve        ***.
*** Introduce new variable which flags  a problem               ***.
*******************************************************************.

compute Flag02=0.
compute Flag03=0.

*******************************************************************.
*** gdje postoje unesene vrijednosti nula i vise                ***.
*** counting how many cases in each gnd, mun, entity and bih    ***.
*******************************************************************.

IF mbc1_q02 gt 0 Flag02= 1 .
VARIABLE LABELS Flag02 'Gives 1 where there is data' .
IF mbc1_q03 gt 0 Flag03= 1 .
VARIABLE LABELS Flag03 'Gives 1 where there is data' .

*******************************************************************.
*** Izracunam agregate u novi fajl za GND                       ***.
*** Calculate aggregates for GND                                ***.
*******************************************************************.

missing values mbc1_q02 mbc1_q03 (-1, 0).
freq /var mbc1_q02 mbc1_q03.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart1_Gnd.sav'
  /BREAK=muncode gnd mbc1_q00
  /Gdata02 = SUM(Flag02) /Gmed02 = MEDIAN(mbc1_q02) 
  /Gdata03 = SUM(Flag03) /Gmed03 = MEDIAN(mbc1_q03).

*******************************************************************.
*** Izracunam agregate u novi fajl za MUN                       ***.
*** Calculate aggregates for MUN                                ***.
*******************************************************************.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart1_Mun.sav'
  /BREAK=muncode mbc1_q00
  /Mdata02 = SUM(Flag02)/Mmed02 = MEDIAN(mbc1_q02) 
  /Mdata03 = SUM(Flag03)/Mmed03 = MEDIAN(mbc1_q03).

*******************************************************************.
*** Izracunam SD i MEDIAN  za entitet set                       ***.
*** Calculate aggregates for ENTITY                             ***.
*******************************************************************.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart1_Ent.sav'
  /BREAK= entity mbc1_q00
  /edata02 = SUM(Flag02) /eMed02 = MEDIAN(mbc1_q02) /eStd02  = SD(mbc1_q02)
  /edata03 = SUM(Flag03) /eMed03 = MEDIAN(mbc1_q03) /eStd03  = SD(mbc1_q03).

*******************************************************************.
*** Izracunam SD i MEDIAN  za dati set                          ***.
*** Calculate aggregates for B&H                                ***.
*******************************************************************.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart1_bih.sav'
  /BREAK=mbc1_q00
  /Med02 = MEDIAN(mbc1_q02) / Std02  = SD(mbc1_q02)
  /Med03 = MEDIAN(mbc1_q03) / Std03  = SD(mbc1_q03).

*******************************************************************.
*** Spajam fajl sa medianom i std devijac                       ***.
*** Merging with new file                                       ***.
*******************************************************************.

sort cases by mbc1_q00.

MATCH FILES /FILE=*
 /TABLE='c:\bih\tempnonfoodpart1_bih.sav'
 /BY mbc1_q00.

*******************************************************************.
*** Spajam fajl sa agregatima GND                               ***.
*** Merging GND info with file in memory                        ***.
*******************************************************************.

sort cases  by
muncode gnd mbc1_q00.

MATCH FILES /FILE=*
 /TABLE='c:\bih\tempnonfoodpart1_Gnd.sav'
 /BY muncode gnd mbc1_q00.

*******************************************************************.
*** Spajam fajl sa agregatima MUN                               ***.
*** Merging MUN info with file in memory                        ***.
*******************************************************************.

sort cases by muncode mbc1_q00.

MATCH FILES /FILE=*
 /TABLE='c:\bih\tempnonfoodpart1_Mun.sav'
 /BY muncode mbc1_q00.

*******************************************************************.
*** Spajam fajl sa agregatima Entiteta                          ***.
*** Merging Entity info with file in memory                     ***.
*******************************************************************.

sort cases by entity mbc1_q00.

MATCH FILES /FILE=*
 /TABLE='c:\bih\tempnonfoodpart1_Ent.sav'
 /BY entity mbc1_q00.

*******************************************************************.
*** pa vratim -1 ponovo u igru                                  ***.
*** again Include cases with -1                                 ***.
*******************************************************************.

missing values mbc1_q02 mbc1_q03 ().

*******************************************************************.
*** Replace missing values with                                 ***.
*** MEDIANS if there are more than 5 cases                      ***.
*******************************************************************.
*** replace 777's & 888's with median                           ***.
*** purchase                                                    ***.
*******************************************************************.

if (gdata02 ge 5) amed02=gmed02.
if (gdata02 lt 5 and mdata02 ge 5) amed02 = mmed02.
if (gdata02 lt 5 and mdata02 lt 5 and edata02 ge 5) amed02=emed02.
if (gdata02 lt 5 and mdata02 lt 5 and edata02 lt 5) amed02=med02.

if (mbc1_q02 eq -1) mbc1_q02=amed02.

*******************************************************************.
*** replace 777's & 888's with median                           ***.
*** gifts                                                       ***.
*******************************************************************.

if (gdata03 ge 5) amed03=gmed03.
if (gdata03 lt 5 and mdata03 ge 5) amed03 = mmed03.
if (gdata03 lt 5 and mdata03 lt 5 and edata03 ge 5) amed03=emed03.
if (gdata03 lt 5 and mdata03 lt 5 and edata03 lt 5) amed03=med03.
if (mbc1_q03 eq -1) mbc1_q03=amed03.

*******************************************************************.
*** replace outliers with MEDIAN+6*SD                           ***.
*** purchase                                                    ***.
*******************************************************************.

if (mbc1_q02 ge (med02+(6*std02))) | (mbc1_q02 lt (med02-(6*std02))))  mbc1_q02=amed02.
if (mbc1_q03 ge (med03+(6*std03))) | (mbc1_q03 lt (med03-(6*std03))))  mbc1_q03=amed03.

*******************************************************************.
*** Zamjenjujem "." vrijednost nulom "0" radi sabiranja         ***.
*** Replace cases " . " with " 0 " for calculating totals       ***.
*******************************************************************.

if (sysmis(mbc1_q02)) mbc1_q02=0.
if (sysmis(mbc1_q03)) mbc1_q03=0.
 
*******************************************************************.
*** Create annual amounts                                       ***.
*******************************************************************.

compute m11c1ex=mbc1_q02*12.
compute m11c1gf=mbc1_q03*12.
variable labels m11c1ex 'Yrly exp., M11C1'
 /m11c1gf 'Yrly gifts, M11C1'.

*******************************************************************.
*** Break by the variables that identify the household          ***.
*** Sum that is at the hhld level                               ***.
*******************************************************************.

AGGREGATE
  /OUTFILE='C:\bih\nonfoodpart1.sav'
  /BREAK=muncode gnd numist hid
  /m11c1_ex 'Yrly exp.M11C1' =sum(m11c1ex)
  /m11c1_gf 'Yrly gift, M11C1' = sum(m11c1gf).

*********************************.
*** Otvaram file za analizu   ***.
*** Open file                 ***.
*********************************.

get file='c:\bih\nonfoodpart1.sav'.

*********************************.
*** Provjera frekvencija      ***.
*** Check frequencies         ***.
*********************************.
freq /var m11c1_ex m11c1_gf/statistics default median.

compute totnfc1= m11c1_ex + m11c1_gf.
variable labels totnfc1 'Yrly cons. from M11C1'.
freq /var totnfc1 /format notable /statistics default median mean.

*********************************.
***   Save the result file    ***.
*********************************.

save outfile='c:\bih\nonfoodpart1.sav'.

