***********************************************.
*** BiH 2001 LSMS country level data        ***.
***                                         ***.
*** Program file: NONFOODPART1 sps          ***.
***                                         ***.
*** Uses data file C:\BIH\M11_C2 sav        ***.
*** Output file: C:\BIH\NONFOODPART2 sav    ***.
***                                         ***.
*** For the Consumption aggregate           ***.
*** Aggregates and cleans annual non-food   ***.
*** expenditures from module 11, part C2    ***.
***********************************************.

***********************************************.
*** Otvaram file za analizu                 ***.
*** Open file to analyze                    ***.
***********************************************.

get file='c:\bih\m11_c2.sav'.

***********************************************.
*** Provjera frekvencija                    ***.
*** Check frequencies                       ***.
***********************************************.

freq /var mbc2_q4b mbc2_q05 mbc2_q06 /statistics default median.

********************************************************************.
*** Ponistavamo sva setovanja missing values                     ***.
*** Clear all settings for missing values                        ***.
********************************************************************.

missing values mbc2_q4b mbc2_q05 mbc2_q06 ().

********************************************************************.
*** Postavljamo vrijednosti svih missing na istu konstantu       ***.
*** radi jednostavnijeg pregleda                                 ***.
*** Set all missing values to const (-1)                         ***.
*** There is one mistaken case with missing value of 5 digits    ***.
********************************************************************.

recode mbc2_q05 (77777, 777777 thru  highest=-1).
recode mbc2_q06 (777777 thru  highest=-1).

***********************************************.
*** Provjeravamo uspjeh                     ***.
*** Check the result                        ***.
***********************************************.

freq /var mbc2_q05 mbc2_q06 /statistics default median. 

*******************************************************************.
*** Pravim listing vrijednosti koje ne odgovaraju               ***.
*** List all cases for which answers don't match                ***.
*** Ima potrosnja- nema vrijednosti                             ***.
*** have  'yes' for consumption, but no values                  ***.
*******************************************************************.

temporary.
select if (mbc2_q4b eq 1 and (mbc2_q05 eq -1 or mbc2_q06 eq -1)).
list /var muncode gnd numist hid mbc2_q00 mbc2_q4b mbc2_q05 mbc2_q06.

**********************************************.
*** Nema potrosnje- postoje vrijednosti    ***.
*** have  'no' for consumption, but there  ***.
*** are values                             ***.
**********************************************.

temporary.
select if (mbc2_q4b eq 2 and (mbc2_q05 > 0  or mbc2_q06 > 0 )).
list /var muncode gnd numist hid mbc2_q00 mbc2_q4b mbc2_q05 mbc2_q06.

*******************************************************************.
*** Uklanjam odgovor 'yes' gdje  potrosnja nema vrijednost      ***.
*** Remove 'yes' where there are both 0 values                  ***.
*******************************************************************.

if ( mbc2_q4b eq 1 and (mbc2_q05 eq 0 and mbc2_q06 eq 0)) mbc2_q4b=2.

*******************************************************************.
*** Validne vrijednosti iz seta nema potrosnje prebacujem u ima ***.
*** potrosnje                                                   ***.       
*** For record with no, but has values, change mbc2_q4b to 1    ***.       
*******************************************************************.

if (mbc2_q4b eq 2 and (mbc2_q05 > 0  or mbc2_q06 > 0 ))  mbc2_q4b=1.

*******************************************************************.
*** snimam u medjufajl radi kontrole rezultata                  ***.
*** make new file for those who have consumption AND have       ***.
*** values for consumption                                      ***.
*******************************************************************.

temporary.
select if (mbc2_q4b eq 1).
save outfile='c:\bih\tempnonfoodpart2_all.sav'.

*******************************************************************.
*** Racunam medijane i standardne devijacije                    ***.
*** Calculate MEDIAN and SD                                     ***.
*******************************************************************.
*******************************************************************.
*** Koristim novi fajl                                          ***.
*** Use the new file                                            ***. 
*******************************************************************.

get file='c:\bih\tempnonfoodpart2_all.sav'.

**************************************************.
*** Prvo se rijesim ovih -1 vrijednosti        ***.
*** Exclude values with -1 for this            ***.
**************************************************.

missing values mbc2_q05 mbc2_q06 (-1).

******************************************************************.
***Uvodim varijable pomocu kojih cu da brojim slucajeve        ***.
***Introduce new variable                                      ***.
******************************************************************.

compute Flag05=0.
compute Flag06=0.

********************************************************************.
*** gdje postoje unesene vrijednosti nula i vise                 ***.
*** for counting how many cases in each gnd, mun, entity         ***.
*** and country                                                  ***.
********************************************************************.

IF mbc2_q05 gt 0 Flag05= 1 .
VARIABLE LABELS Flag05 'Gives 1 where there is data' .
IF mbc2_q06 gt 0 Flag06= 1 .
VARIABLE LABELS Flag06 'Gives 1 where there is data' .

**************************************************.
*** Izracunam agregate u novi fajl za GND      ***.
*** Calculate aggregates for GND               ***.
**************************************************.

missing values mbc2_q05 (-1, 0).
missing values mbc2_q06 (-1, 0).
freq /var mbc2_q05 mbc2_q06.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart2_Gnd.sav'
  /BREAK=muncode gnd mbc2_q00
  /Gdata05 = SUM(Flag05) /Gmed05 = MEDIAN(mbc2_q05)
  /Gdata06 = SUM(Flag06) /Gmed06 = MEDIAN(mbc2_q06).

**************************************************.
*** Izracunam agregate u novi fajl za MUN      ***.
*** Calculate aggregates for MUN               ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart2_Mun.sav'
  /BREAK=muncode mbc2_q00
  /Mdata05 = SUM(Flag05)/Mmed05 = MEDIAN(mbc2_q05) 
  /Mdata06 = SUM(Flag06)/Mmed06 = MEDIAN(mbc2_q06).

**************************************************.
*** Izracunam SD i MEDIAN  za entitet set      ***.
*** Calculate aggregates for ENTITY            ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart2_Ent.sav'
  /BREAK= entity mbc2_q00
  /edata05 = SUM(Flag05) /eMed05 = MEDIAN(mbc2_q05)/eStd05  = SD(mbc2_q05)
  /edata06 = SUM(Flag06) /eMed06 = MEDIAN(mbc2_q06)/eStd06  = SD(mbc2_q06).

**************************************************.
*** Izracunam SD i MEDIAN  za dati set         ***.
*** Calculate aggregates for B&H               ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart2_bih.sav'
  /BREAK=mbc2_q00
  /Med05 = MEDIAN(mbc2_q05)/Std05  = SD(mbc2_q05)
  /Med06 = MEDIAN(mbc2_q06)/Std06  = SD(mbc2_q06).

**************************************************.
*** Spajam fajl sa medianom i std devijac      ***.
*** Merging with new file                      ***.
**************************************************.

sort cases  by mbc2_q00.

MATCH FILES /FILE=*
 /TABLE='C:\bih\tempnonfoodpart2_bih.sav'
 /BY mbc2_q00.

**************************************************.
*** Spajam fajl sa agregatima GND              ***.
*** Merging with new file                      ***.
**************************************************.

sort cases  by muncode gnd mbc2_q00.

MATCH FILES /FILE=*
 /TABLE='C:\bih\tempnonfoodpart2_Gnd.sav'
 /BY muncode gnd mbc2_q00.

**************************************************.
*** Spajam fajl sa agregatima MUN              ***.
*** Merging with new file                      ***.
**************************************************.

sort cases  by muncode mbc2_q00.

MATCH FILES /FILE=*
 /TABLE='C:\bih\tempnonfoodpart2_Mun.sav'
 /BY muncode mbc2_q00.

**************************************************.
*** Spajam fajl sa agregatima ENT              ***.
*** Merging with new file                      ***.
**************************************************.

sort cases  by entity mbc2_q00.

MATCH FILES /FILE=*
 /TABLE='C:\bih\tempnonfoodpart2_Ent.sav'
 /BY entity mbc2_q00.

**************************************************.
*** Pa vratim -1 ponovo u igru                 ***.
*** Include cases with -1                      ***.
**************************************************.

missing values mbc2_q05 mbc2_q06 ().

*******************************************************************.
*** Replace missing values with MEDIANS if there are more than  ***.
*** 5 cases --for purchases and then for gifts                  ***.
*******************************************************************.

if (gdata05 ge 5) amed05=gmed05.
if (gdata05 lt 5 and mdata05 ge 5) amed05 = mmed05.
if (gdata05 lt 5 and mdata05 lt 5 and edata05 ge 5) amed05=emed05.
if (gdata05 lt 5 and mdata05 lt 5 and edata05 lt 5) amed05=med05.

if (mbc2_q05 eq -1) mbc2_q05=amed05.

if (gdata06 ge 5) amed06=gmed06.
if (gdata06 lt 5 and mdata06 ge 5) amed06 = mmed06.
if (gdata06 lt 5 and mdata06 lt 5 and edata06 ge 5) amed06=emed06.
if (gdata06 lt 5 and mdata06 lt 5 and edata06 lt 5) amed06=med06.

if (mbc2_q06 eq -1) mbc2_q06=amed06.

*******************************************************************.
*** replace outliers with MEDIAN+6*SD                           ***.
*** purchase                                                    ***.
*******************************************************************.

if (mbc2_q05 ge (med05+(6*std05))) | (mbc2_q05 lt (med05-(6*std05))))  mbc2_q05=amed05.

*******************************************************************.
*** Zamjenjujem extr vrijednost                                 ***.
*** replace outliers with median                                ***.
*** gifts                                                       ***.
*******************************************************************.

if (mbc2_q06 ge (med06+(6*std06))) | (mbc2_q06 lt (med06-(6*std06))))  mbc2_q06=amed06.

****************************************************************.
*** Zamjenjujem "." vrijednost nulom "0" radi sabiranja      ***.
*** Replace cases " . " with " 0 " for calculating totals    ***.
****************************************************************.

if (sysmis(mbc2_q05)) mbc2_q05=0.
if (sysmis(mbc2_q06)) mbc2_q06=0.

*************************************************************************************.
*** EXCLUSIONS (For double counting and lumpy expences)                           ***.
*** For double counting we are excluding items: 15 (hhld appliances)              ***.
***  23 (wehicles), 27  (sound and picture recording equipment),                  ***.
***  28 (photography equip) and 29 (data processing equip), 32  already included  ***.
***  in M2 (Durables) -- 46, gifts and charities is excluded as it is not hhld    ***.
***  consumption, for lumpy expenses we are excluding 47 (ceremonies) and         ***.
***  48 (losses)                                                                  ***.
*************************************************************************************.

select if ((mbc2_q00 ge 1 & mbc2_q00 le 14) or (mbc2_q00 ge 16 & mbc2_q00 le 22) or
 (mbc2_q00 ge 24 & mbc2_q00 le 26) or (mbc2_q00 ge 30 & mbc2_q00 le 31) or (mbc2_q00 ge 33 & mbc2_q00 le 45)).

save outfile='C:\bih\tempnonfoodpart2_clean.sav'.

compute m11c2ex=mbc2_q05.
compute m11c2gf=mbc2_q06.
variable labels m11c2ex 'Yrly exp., M11C2'
 /m11c2gf 'Yrly gifts, M11C2'.

****************************************************************************.
*** note: break by the variables that identify the household as you want ***.
*** a sum that is at the hhld level                                      ***.
****************************************************************************.

AGGREGATE
  /OUTFILE='C:\bih\tempnonfoodpart2.sav'
  /BREAK=muncode gnd numist hid
  /m11c2_ex 'Yrly exp.M11C2' =sum(m11c2ex)
  /m11c2_gf 'Yrly gift, M11C2' = sum(m11c2gf).


*********************************.
*** Otvaram file za analizu   ***.
*** Open file                 ***.
*********************************.

get file='C:\bih\tempnonfoodpart2.sav'.

*********************************.
*** Provjera frekvencija      ***.
*** Check frequencies         ***.
*********************************.

freq /var m11c2_ex m11c2_gf/statistics default median.

compute totnfc2= m11c2_ex + m11c2_gf.
variable labels totnfc2 'Yrly nonfood cons. from M11C2'.
freq /var totnfc2 /format notable /statistics default median mean.

*********************************.
***   Save the result file    ***.
*********************************.

save outfile='c:\bih\nonfoodpart2.sav'.

