**************************************************.
*** BiH, 2001, LSMS Country Level data         ***.
***                                            ***.
*** Program file: POV_INDICATORS sps           ***.
*** Data file used: C:\BIH\POVERTY1 sav        ***.
***                                            ***.
*** This file displays the poverty variables   ***.
*** by entity and municipality type as well as ***.
*** at the country level                       ***.
*** It also examines inequality by calculating ***.
*** the Lorenz Curve and the Gini Coefficient  ***.
**************************************************.

**************************************************.
***  REPUBLIKA SRPSKA                          ***.
**************************************************.

get file='c:\bih\poverty1.sav'.
select if (entity eq 1).
weight by whhd.
freq /var poor gap severity /format notable /statistics default mean.

means tables=poor by mun_type.
means tables=gap by mun_type.
means tables=severity by mun_type.
means tables=shortfal by mun_type.

**************************************************.
*** Inequality:  Gini Coefficient for RS       ***.
**************************************************.

compute tempvar=1.

**************************************************.
***Create entity level quintil and deciles     ***.
**************************************************.

WEIGHT by whhd.

rank variables=pcayrcon (A) /RANK /NTILES (5) /PRINT=YES
  /TIES=MEAN.

rename variable (npcayrco=quintile).

rank variables=pcayrcon (A) /RANK /NTILES (10) /PRINT=YES
  /TIES=MEAN.

rename variable (npcayrco=decile).

**************************************************.
*** Average consumption by quintile and by     ***.
*** decile in RS                               ***. 
**************************************************.

means tables=pcayrcon by quintile /cells mean count sum.
  
means tables=pcayrcon by decile /cells mean count sum.

weight off.

sort cases by muncode gnd numist hid.

*******************************************************************************************.
***  First have to create variables X and Y which are the percentage accumulated values ***.
***  of the population and of consumption (both orderd from lowest to highest consumption**.
***  For each of the variable need to calculate the accumulated value and the total value**.
***  To avoid problems with the weights, incorporate in consumption and population, from **.
***  the beginning by multiplying consumption by the weights and making the weight       **.
***  variable the population that each hhld represents                                   **.
*******************************************************************************************.

**************************************************.
*** Order by pc consumption level              ***. 
**************************************************.

COMPUTE co.t.h = pcayrcon * whhd.
VARIABLE LABELS co.t.h 'Pc adj consumption, total amount represented by each hhld'.
COMPUTE per.t.h = whhd.
VARIABLE LABELS per.t.h 'total number of persons each hhld represents'.

**************************************************.
*** Sum all to obtain data at entity level     ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\gini1_rs.sav'
  /BREAK=tempvar
  /totconbh 'Total consumption BiH' = SUM(co.t.h)
  /totpopbh 'Total population BiH' = SUM(per.t.h).
MATCH FILES /FILE=*
 /TABLE='C:\bih\gini1_rs.sav'
 /BY tempvar.

**************************************************.
*** Calculate the proportion of the population ***. 
*** and consumption that each hhld represents  ***.
**************************************************.

COMPUTE proporco = co.t.h / totconbh .
VARIABLE LABELS proporco 'Proporcion de consumo' .
COMPUTE proporpo = per.t.h / totpopbh .
VARIABLE LABELS proporpo 'Proporcion de # de personas' .
EXECUTE .

**************************************************.
*** Calculate the accumulated proportion of    ***.
*** consumption and population                 ***.
**************************************************.

sort cases by pcayrcon (A).

CREATE
  /y.i=CSUM(proporco).
CREATE
  /x.i=CSUM(proporpo).
COMPUTE li45 = y.i .
EXECUTE .

formats x.i y.i li45 (f7.5) .
variable labels y.i 'Cumulative consumption for Lorenz'
                x.i 'Cumulative population for Lorenz'
                li45'45 degree line for lorenz'  .

**************************************************.
*** Lorenz Curve for RS                        ***.
**************************************************.

graph /scatterplot(overlay)=x.i li45  WITH y.i y.i (PAIR)
  /MISSING=LISTWISE .

**************************************************.
*** Calculate the Gini coefficient             ***.
***                                            ***.
*** 1-Calculate (X(i)-X(i-1)) * (Y(i) + Y(i-1))***.
**************************************************.

COMPUTE gi1 = (x.i - LAG(x.i)) * (y.i + LAG(y.i)) .

**************************************************.
*** Sum all values                             ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\gini2_rs.SAV'
  /BREAK=tempvar
  /sum.gi1 'SUM {[X(i)-X(i-1)] * [Y(i)+Y(i-1)]}' = SUM(gi1).
MATCH FILES /FILE=*
 /TABLE='C:\bih\gini2_rs.SAV'
 /BY tempvar.
EXECUTE.

**************************************************.
*** Calculate the GINI                         ***.
**************************************************.

COMPUTE gini = 1 - sum.gi1 .
VARIABLE LABELS gini 'GINI Coefficient' .
freq /var gini /statistics mean.

save /outfile='c:\bih\gini3_rs.sav'.

****************************************************.
*** create top value per decile to get percentage***.
*** of consumption to each decile                ***.
****************************************************.

sort cases by y.i.
aggregate /outfile='c:\bih\condecrs.sav'
 /break decile
 /decons 'Top value in decile of cons' =last(y.i).

get file='c:\bih\condecrs.sav'.
compute percon1=lag(decons).
compute percon2=decons-percon1.
if (decile eq 1) percon2=decons.

list.

**************************************************.
***  FEDERATION                                ***.
**************************************************.

get file='c:\bih\poverty1.sav'.
select if (entity eq 2).
weight by whhd.
freq /var poor gap severity /format notable /statistics default mean.

means tables=poor by mun_type.
means tables=gap by mun_type.
means tables=severity by mun_type.
means tables=shortfal by mun_type.

*****************************************.
*** Gini for Federation               ***.
*****************************************.

compute tempvar=1.

**************************************************.
*** Create entity level quintil and deciles    ***.
**************************************************.

WEIGHT by whhd.

rank variables=pcayrcon (A) /RANK /NTILES (5) /PRINT=YES
  /TIES=MEAN.

rename variable (npcayrco=quintile).

rank variables=pcayrcon (A) /RANK /NTILES (10) /PRINT=YES
  /TIES=MEAN.

rename variable (npcayrco=decile).

***************************************************.
*** Average consumption by quintile and by      ***.
*** decile in FED                               ***. 
***************************************************.

means tables=pcayrcon by quintile /cells mean count sum.
  
means tables=pcayrcon by decile /cells mean count sum.

weight off.

SORT CASES BY muncode gnd numist hid.

*******************************************************************************************.
***  First have to create variables X and Y which are the percentage accumulated values ***.
***  of the population and of consumption (both orderd from lowest to highest consumption**.
***  For each of the variable need to calculate the accumulated value and the total value**.
***  To avoid problems with the weights, incorporate in consumption and population, from **.
***  the beginning by multiplying consumption by the weights and making the weight       **.
***  variable the population that each hhld represents                                   **.
*******************************************************************************************.

**************************************************.
*** Order by per capita consumption level      ***. 
**************************************************.

COMPUTE co.t.h = pcayrcon * whhd.
VARIABLE LABELS co.t.h 'Pc adj consumption, total amount represented by each hhld'.
COMPUTE per.t.h = whhd.
VARIABLE LABELS per.t.h 'total number of persons each hhld represents'.

**************************************************.
*** Sum all to obtain data at entity level     ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\gini1_fe.sav'
  /BREAK=tempvar
  /totconbh 'Total consumption BiH' = SUM(co.t.h)
  /totpopbh 'Total population BiH' = SUM(per.t.h).
MATCH FILES /FILE=*
 /TABLE='C:\bih\gini1_fe.sav'
 /BY tempvar.

**************************************************.
*** Calculate the proportion of the population ***.
*** and consumption that each hhld represents  ***.
**************************************************.

COMPUTE proporco = co.t.h / totconbh .
VARIABLE LABELS proporco 'Proporcion de consumo' .
COMPUTE proporpo = per.t.h / totpopbh .
VARIABLE LABELS proporpo 'Proporcion de # de personas' .
EXECUTE .

**************************************************.
*** Calculate the accumulated proportion of    ***.
*** consumption and population                 ***.
**************************************************.

sort cases by pcayrcon (A) .

CREATE
  /y.i=CSUM(proporco).
CREATE
  /x.i=CSUM(proporpo).
COMPUTE li45 = y.i .
EXECUTE .

formats x.i y.i li45 (f7.5) .
variable labels y.i 'Cumulative consumption for Lorenz'
                x.i 'Cumulative population for Lorenz'
                li45'45 degree line for lorenz'  .

**************************************************.
*** Lorenz Curve for the Federation            ***.
**************************************************.

graph /scatterplot(overlay)=x.i li45  WITH y.i y.i (PAIR)
  /MISSING=LISTWISE .

**************************************************.
*** Calculate the Gini coefficient             ***.
***                                            ***.
*** 1-Calculate (X(i)-X(i-1)) * (Y(i) + Y(i-1))***.
**************************************************.

COMPUTE gi1 = (x.i - LAG(x.i)) * (y.i + LAG(y.i)) .

**************************************************.
*** Sum all values                             ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\gini2_fe.SAV'
  /BREAK=tempvar
  /sum.gi1 'SUM {[X(i)-X(i-1)] * [Y(i)+Y(i-1)]}' = SUM(gi1).
MATCH FILES /FILE=*
 /TABLE='C:\bih\gini2_fe.SAV'
 /BY tempvar.
EXECUTE.

**************************************************.
*** Calculate the GINI Federation              ***.
**************************************************.

COMPUTE gini = 1 - sum.gi1 .
VARIABLE LABELS gini 'GINI Coefficient' .
freq /var gini /statistics mean.

save /outfile='c:\bih\gini3_fe.sav'.

****************************************************.
*** create top value per decile to get percentage***.
*** of consumption to each decile                ***.
****************************************************.

sort cases by y.i.
aggregate /outfile='c:\bih\condecfe.sav'
 /break decile
 /decons 'Top value in decile of cons' =last(y.i).

get file='c:\bih\condecfe.sav'.
compute percon1=lag(decons).
compute percon2=decons-percon1.
if (decile eq 1) percon2=decons.

list.

**************************************************.
***  BiH:  For the whole country               ***.
**************************************************.

get file='c:\bih\poverty1.sav'.
weight  by whhd.
freq /var poor gap severity /format notable /statistics default mean.

means tables=poor by mun_type.
means tables=gap by mun_type.
means tables=severity by mun_type.
means tables=shortfal by mun_type.

*****************************************.
*** Gini, Lorenz for BiH              ***.
*****************************************.

compute tempvar=1.

**************************************************.
*** Create country level quintil and deciles   ***.
**************************************************.

rank variables=pcayrcon (A) /RANK /NTILES (5) /PRINT=YES
  /TIES=MEAN .

rename variable (npcayrco=quintile).

rank variables=pcayrcon (A) /RANK /NTILES (10) /PRINT=YES
  /TIES=MEAN .

rename variable (npcayrco=decile).

**************************************************.
***Average consumption by quintile, decile     ***. 
**************************************************.

means tables=pcayrcon by quintile /cells mean count sum.
means tables=pcayrcon by decile /cells mean count sum.

weight off.

sort cases by muncode gnd numist hid.

*******************************************************************************************.
***  First have to create variables X and Y which are the percentage accumulated values ***.
***  of the population and of consumption (both orderd from lowest to highest consumption**.
***  For each of the variable need to calculate the accumulated value and the total value**.
***  To avoid problems with the weights, incorporate in consumption and population, from **.
***  the beginning by multiplying consumption by the weights and making the weight       **.
***  variable the population that each hhld represents                                   **.
*******************************************************************************************.

**************************************************.
*** Order by pc consumption level              ***. 
**************************************************.

COMPUTE co.t.h = pcayrcon * whhd.
VARIABLE LABELS co.t.h 'Pc adj consumption, total amount represented by each hhld'.
COMPUTE per.t.h = whhd.
VARIABLE LABELS per.t.h 'total number of persons each hhld represents'.

**************************************************.
***Sum all to obtain data at country level     ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\gini1_bh.sav'
  /BREAK=tempvar
  /totconbh 'Total consumption BiH' = SUM(co.t.h)
  /totpopbh 'Total population BiH' = SUM(per.t.h).
MATCH FILES /FILE=*
 /TABLE='C:\bih\gini1_bh.sav'
 /BY tempvar.

**************************************************.
*** Calculate the proportion of the population ***.
*** and consumption that each hhld represents  ***.
**************************************************.

COMPUTE proporco = co.t.h / totconbh .
VARIABLE LABELS proporco 'Proporcion de consumo' .
COMPUTE proporpo = per.t.h / totpopbh .
VARIABLE LABELS proporpo 'Proporcion de # de personas' .
EXECUTE .

**************************************************.
*** Calculate the accumulated proportion of    ***.
*** consumption and population                 ***.
**************************************************.

sort cases by pcayrcon (A).

CREATE
  /y.i=CSUM(proporco).
CREATE
  /x.i=CSUM(proporpo).
COMPUTE li45 = y.i .
EXECUTE .

formats x.i y.i li45 (f7.5) .
variable labels y.i 'Cumulative consumption for Lorenz'
                x.i 'Cumulative population for Lorenz'
                li45'45 degree line for lorenz'  .

**************************************************.
*** Lorenz Curve for BiH                       ***.
**************************************************.

GRAPH
  /SCATTERPLOT(OVERLAY)=x.i li45  WITH y.i y.i (PAIR)
  /MISSING=LISTWISE .

**************************************************.
*** Calculate the Gini coefficient             ***.
***                                            ***.
*** 1-Calculate (X(i)-X(i-1)) * (Y(i) + Y(i-1) ***.
**************************************************.

COMPUTE gi1 = (x.i - LAG(x.i)) * (y.i + LAG(y.i)) .

**************************************************.
*** Sum all values                             ***.
**************************************************.

AGGREGATE
  /OUTFILE='C:\bih\gini2_bh.SAV'
  /BREAK=tempvar
  /sum.gi1 'SUM {[X(i)-X(i-1)] * [Y(i)+Y(i-1)]}' = SUM(gi1).
MATCH FILES /FILE=*
 /TABLE='C:\bih\gini2_bh.SAV'
 /BY tempvar.
EXECUTE.

**************************************************.
*** Calculate the GINI                         ***.
**************************************************.

COMPUTE gini = 1 - sum.gi1 .
VARIABLE LABELS gini 'GINI Coefficient' .
freq /var gini /statistics mean.

save /outfile='c:\bih\gini3_bh.sav'.

****************************************************.
*** create top value per decile to get percentage***.
*** of consumption to each decile                ***.
****************************************************.

sort cases by y.i.
aggregate /outfile='c:\bih\condecbh.sav'
 /break decile
 /decons 'Top value in decile of cons' =last(y.i).

get file='c:\bih\condecbh.sav'.
compute percon1=lag(decons).
compute percon2=decons-percon1.
if (decile eq 1) percon2=decons.

list.

