***************************************************.
*** BiH, 2001, LSMS, Country Level Data         ***.
***                                             ***.
*** Program file:  PRICEINDEX sps               ***.
*** Data files used: C:\BIH\FOOD_ALL sav        ***.
***                  C:\BIH\HHCHAR sav          ***.
*** Output file: c:\BIH\PRICEINDEX sav          ***.
***                                             ***.
*** This program calculates the price index     ***.
*** based on the full list of unit values       ***.
*** Cijena indeksa                              ***.
***************************************************.

***************************************************.
*** Producing the country level mean unit values***.
***************************************************.

get file='c:\bih\food_all.sav'.
sort cases by muncode gnd numist hid.
match files file=* /table= 'c:\bih\hhchar.sav'
 /by muncode gnd numist hid.
sort cases by mbb_code.

compute foodwght= whhd * tothhqte.
weight by foodwght.

AGGREGATE
  /OUTFILE='C:\bih\b_price_NatUnitPQ.sav'
  /BREAK=mbb_code
  /NUnitpq = Mean(unitvalu).
EXECUTE .

***************************************************.
*** Merging in the data on country level        ***. 
*** national unit values (prices)               ***.
***************************************************.
 
get file='c:\bih\food_all.sav'.

sort cases by mbb_code.

match files /file=* /table='c:\bih\b_price_NatUnitPQ.sav'
 /by mbb_code.

save outfile='c:\bih\foodtem1.sav'.

***************************************************.
*** Valuing purchase in own unit values as      ***.
*** opposed to national prices                  ***.
***************************************************.

get file='C:\bih\foodtem1.sav'.

compute pqun =tothhqte*NUnitpq.
compute pqu = tothhqte*unitvalu.

variable label pqun 'quantity by national prices' 
 / pqu 'quantity by own prices'.

EXECUTE.

AGGREGATE
  /OUTFILE='C:\bih\b_price_HH.sav'
  /BREAK=entity muncode gnd numist hid
  /pqu_HH = SUM(pqu) /pqun_HH=SUM(pqun).

get file='c:\bih\b_price_HH.sav'.
AGGREGATE
  /OUTFILE='C:\bih\PriceIndex.sav'
  /BREAK=entity muncode gnd numist 
  /pqu_N = MEAN(pqu_HH) /pqun_N=MEAN(pqun_HH).

***************************************************.
*** Calculating the price index at the level of ***.
*** NUMIST and saving it in a file Price index  ***.
***************************************************.

get file='C:\bih\PriceIndex.sav'.

compute pindex = pqu_N/pqun_N.
freq /var pindex /format notable /statistics default mean median.

***************************************************.
*** Summary by municipality                     ***.
***************************************************.

means table=pindex by muncode.

sort cases by muncode gnd numist.

save outfile='C:\bih\PriceIndex.sav'.


