*******************************************************.
*** BiH, LSMS 2001, Country level data              ***.
***                                                 ***.
*** Program file:  POVLINE1 sps                     ***.
*** Data files used: c:\BIH\HHCHAR sav              ***.
***                  C:\BIH\FOOD_ALL sav            ***.
***                  C:\BIH\B_PRICE_NATUNITPQ sav   ***.
***                  C:\BIH\CALORIES sav            ***.
***                  C:\BIH\REF_HHLD sav            ***.
*** Output files: C:\BIH\TOTALEXP sav               ***.
***                                                 ***.
*** Create the food poverty line                    ***.
***                                                 ***.
*** Using file FOOD_ALL sav                         ***.
*** which contains the total quantity of foods      ***.
*** consumed by household (including purchased      ***.
*** home production and gifts)                      ***.
***                                                 ***.
*** Select only those households from 11-30         ***.
***   percentile (use file REF_HHLD sav for these)  ***.
***                                                 ***.
*** Calculate the total amount of calories          ***.
*** If per person per day ne 2100, make adjustments ***.
***                                                 ***.
*** Convert back to physical quantities (KG/LT)     ***.
***                                                 ***.
*** Cost the basket at national average prices      ***.
*** This is value of food poverty line              ***.
***                                                 ***.
*******************************************************.

*******************************************************.
*** Create a file at municipal level with just the  ***.
*** weight variables                                ***.
*******************************************************.

get file='c:\bih\hhchar.sav'.
sort cases by muncode.
aggregate /outfile='c:\bih\f_weights.sav'
 /break muncode
 /whhd 'Weight for hhld level file' =first(whhd)
 /wpop 'Weight for ind level file' =first(wpop).

*******************************************************.
*** use file with all foods and total quantity      ***.
*** for each food (both B1 and B2) by hhld          ***.
*******************************************************.

get file='c:\bih\food_all.sav'.

*******************************************************.
*** Bring in weight variable                        ***.
*******************************************************.

sort cases by muncode.
match files file=* /table='c:\bih\f_weights.sav'
  /by muncode.

*******************************************************.
*** add in the national mean unit prices per food   ***.
*** item created with syntax PRICEINDEX sps         ***.
*** Add in the caloric content of each food also    ***.
*** caloric context from USDA tables (CALORIES SAV) ***.
*******************************************************.

sort cases by mbb_code.
match files file=* /table='c:\bih\b_price_NatUnitPQ.sav'
 /table='c:\bih\calories.sav' 
 /by mbb_code.

means table=nunitpq by mbb_code.
means table=cal_unit by mbb_code.

*******************************************************.
*** drop all non-'reference hhlds'                  ***.
*******************************************************.

sort cases muncode gnd numist hid.

match files file=* /table='c:\bih\ref_hhld.sav'
 /by muncode gnd numist hid.

select if (refhhld eq 1).
freq /var refhhld.

compute calories=cal_unit*tothhqte.
compute pcpdcal=(calories/hhldsize)/365.
compute pcqte=(tothhqte/hhldsize)/12.
variable lables calories 'Total q cons*calories per item'
 /pcpdcal 'Percapit, daily q of calories from item'
 /pcqte 'percapita quantity per month kg'.

weight by whhd.

aggregate /outfile='c:\bih\totcal.sav'
 /break mbb_code
 /meanpcqt 'mean pc per month quantity'= mean(pcqte)
 /meancal 'mean calories'= mean(calories)
 /meanpcca 'mean percapita,daily calories' =mean(pcpdcal)
 /meanpric 'natl mean prices'= mean(nunitpq)
 /mcalunit 'calories per unit'=mean(cal_unit).

get file='c:\bih\totcal.sav'.
freq /var all /format notable /statistics default mean median sum.
list.

compute tempvar= 1.

aggregate /outfile='c:\bih\total.sav'
 /break tempvar
 /totalcal 'total calories'= sum(meanpcca).

get file='c:\bih\total.sav'.
list.

get file='c:\bih\totcal.sav'.

*****************************************************.
*** if sumpcca (per capita daily calories) from   ***.
*** all foods is not equal to 2100- need to make  ***.
*** adjustment - factor is 'adjust'               ***.
*****************************************************.

compute tempvar=1.
match files file=* /table='c:\bih\total.sav'
 /by tempvar.

compute adjust=2100/totalcal.

if (meanpcca eq 0) adjcalpc = 0.
if (meanpcca ne 0) adjcalpc=adjust*meanpcca.
if (meanpcca eq 0) newquan=0.
if (meanpcca ne 0) newquan=adjcalpc/mcalunit.
compute costquan=newquan*365*meanpric.

******************************************************.
*** the sum of costquan is the value of the extreme***.
*** poverty line                                   ***.
******************************************************.

aggregate /outfile='c:\bih\totalexp.sav'
 /break tempvar
 /totalexp 'total expend'= sum(costquan).

get file='c:\bih\totalexp.sav'.
list.
