*******************************************************.
*** BiH, LSMS 2001, Country level data              ***.
***                                                 ***.
*** Program file:  POVLINE2 sps                     ***.
*** Data files used: C:\BIH\CONS_AGGREGATE sav      ***.
***                  C:\BIH\TOTALEXP sav            ***.
*** Output file: c:\BIH\POVERTY1 sav                ***.
***                                                 ***.
*** Create the general food poverty line            ***.
***                                                 ***.
*** Value of extreme food line is found in file     ***.
*** TOTALEXP sav  (created using POVLINE1 sps)      ***.
***                                                 ***.
*** Select the households whose total food          ***.
*** expenditure is +/- 5 percent of the food poverty***.
*** line                                            ***.
***                                                 ***.
*** Calculate share of expenditures to food and to  ***.
***   non-food for this group,                      ***.
***                                                 ***.
*** Add this share to the value of the extreme      ***.
*** poverty line:  this is the value of the         ***.
*** general poverty line                            ***.
***                                                 ***.
*******************************************************.

get file='c:\bih\cons_aggregate.sav'.

*******************************************************.
*** bring in value of food poverty line             ***.
*******************************************************.

compute tempvar =1.
match files file=* /table='c:\bih\totalexp.sav'
 /by tempvar.

*******************************************************.
*** use value of food poverty line calculated in    ***.
*** POVLINE1 sps                                    ***.
*******************************************************.

compute extpline=totalexp.
variable label extpline 'Extreme poverty line'.

*******************************************************.
*** compute two variables, per capita adjusted      ***.
*** expenditures on food, and per capita adjusted   ***.
*** expenditures on non-food                        ***.
*******************************************************.

compute food=((foodb1_2+mealsout)/pindex)/hhldsize.
compute nonfood=((rent + utilexp + durables + edexp + nfa1 + nfc1 + nfc2)/pindex)/hhldsize.
variable labels food 'percapita adj. exp. on food'
 /nonfood 'percapita adj exp. on non-food'.

*******************************************************.
*** compute two variables, one share of per capita  ***.
*** adjusted expenditures spent on food and the     ***.
*** the other on non-food                           ***.
*******************************************************.

compute shar_fd= food/pcayrcon.
compute shar_nfd=nonfood/pcayrcon.

******************************************************.
*** Weight the file so that the analysis will be   ***.
*** correct (see Basic Information Document for    ***.
*** details on the sampling weights used here)     ***.
******************************************************.

weight by whhd.

freq /var shar_fd shar_nfd /format notable /statistics default median.

*********************************************************.
*** select those people whose total FOOD expenditures ***.
*** equal the food poverty line (extpline) or are     ***.
*** within +/- five percent of the value of the       ***.
*** extpline                                          ***.
*** Determine what share of their total consumption   ***.
*** is on food and what share is on non-food          ***.
*********************************************************.

temporary.
select if ((food>(extpline-(0.05*extpline))) and (food<(extpline+(0.05*extpline)))).
aggregate /outfile='c:\bih\shar_fd.sav'
 /break tempvar
 /psharfd 'Share food of foodpoor' = mean(shar_fd).

match files file=* /table='c:\bih\shar_fd.sav'
 /by tempvar.

temporary.
select if ((food>(extpline-(0.05*extpline))) and (food<(extpline+(0.05*extpline)))).
freq /var psharfd shar_fd shar_nfd /format notable /statistics mean.
 
************************************************************.
*** compute the general poverty line so that food        ***.
*** consumption is equal to the share of this group,     ***.
*** and non-food spending is equal to the share of       ***.
*** non-food consumption of this group                   ***.
************************************************************.

compute genpline=extpline/(psharfd).
freq /var genpline /format notable /statistics mean min max.

******************************************************.
*** Create basic poverty variables, POOR if per    ***.
*** capita consumption is less than the value of   ***.
*** the general poverty line, and EXTPOOR if the   ***.
*** value of per capita consumption is below the   ***.
*** value of the extreme poverty line              ***.
******************************************************.

compute poor=0.
if (pcayrcon lt genpline) poor=1.
compute extpoor=0.
if (pcayrcon lt extpline) extpoor=0.

******************************************************.
*** Now construct the three poverty measures in the***.
*** FGT Index (see Welfare in BiH paper for more   ***.
*** information on this index and measures         ***.
***                                                ***.
*** The following gives the headcount measure of   ***.
*** poverty or the percentage of the population    ***.
*** that is poor (or extremely poor)               ***.
******************************************************.

freq /var poor extpoor.

means tables=poor by entity.

rank /variables = pcayrcon 
 /ntiles (10).

******************************************************.
*** The following calculates the poverty gap       ***.
******************************************************.

compute gap= 0.
if (poor eq 1) gap = (genpline-pcayrcon)/genpline.
means table=gap by entity.

******************************************************.
*** The following calculates the severity of poverty**.
******************************************************.

compute severity=0.
if (poor eq 1) severity = ((genpline-pcayrcon)/genpline)*((genpline-pcayrcon)/genpline).
means table=severity by entity.

if (poor eq 1) shortfal = (genpline-pcayrcon)/genpline.
means table=shortfal by entity.

******************************************************.
*** Exploring differences between the poor and the ***.
*** non-poor                                       ***.
******************************************************.

temporary.
select if (poor eq 1).
means table=pcayrcon by entity.

temporary.
select if (poor eq 1).
 means tables=adult by entity.

temporary.
select if (poor eq 1).
 means tables=child by entity.

freq /var pcayrcon / format notable /statistics default median.

freq /var pcayrcon / format notable /ntiles=10.

save /outfile='c:\bih\poverty1.sav'.
